# Example Package

This is REST API wrapper package to communicate with IxNetwork
The actual code is available at github https://github.com/ParthibanRamachandran/IxNetwork/tree/master/RestApi/Python/Modules

This is forked project from OpenIxia community. with changes to handle the requests based on sessions and fixing of few errors.
